# Velogames data scraper

Parses data from [velogames.com](https://www.velogames.com/) and outputs it into
a CSV file for further processing.

Possible output commands:

- ``teams``:  Parse all teams in a league
- ``riders``: Parse all selected riders in the league
- ``scores``: Parse scores for all different events in the league
